import PageEditor from './helpers/PageEditor';


(function initCMS() {
 /* PageEditor.initAll();*/
}());
